==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/body/impl/BodySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.body.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.architecture.invocable.InvocableObjectSet;
import io.ciera.tool.sql.architecture.invocable.impl.InvocableObjectSetImpl;
import io.ciera.tool.sql.ooaofooa.body.BlockSet;
import io.ciera.tool.sql.ooaofooa.body.Body;
import io.ciera.tool.sql.ooaofooa.body.BodyInComponentSet;
import io.ciera.tool.sql.ooaofooa.body.BodyInElementSet;
import io.ciera.tool.sql.ooaofooa.body.BodySet;
import io.ciera.tool.sql.ooaofooa.body.BridgeBodySet;
import io.ciera.tool.sql.ooaofooa.body.DerivedAttributeBodySet;
import io.ciera.tool.sql.ooaofooa.body.FunctionBodySet;
import io.ciera.tool.sql.ooaofooa.body.OperationBodySet;
import io.ciera.tool.sql.ooaofooa.body.ProvidedOperationBodySet;
import io.ciera.tool.sql.ooaofooa.body.ProvidedSignalBodySet;
import io.ciera.tool.sql.ooaofooa.body.RequiredOperationBodySet;
import io.ciera.tool.sql.ooaofooa.body.RequiredSignalBodySet;
import io.ciera.tool.sql.ooaofooa.body.StateActionBodySet;
import io.ciera.tool.sql.ooaofooa.body.TransitionActionBodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.BlockSetImpl;
import io.ciera.tool.sql.ooaofooa.body.impl.BodyInComponentSetImpl;
import io.ciera.tool.sql.ooaofooa.body.impl.BodyInElementSetImpl;
import io.ciera.tool.sql.ooaofooa.body.impl.BridgeBodySetImpl;
import io.ciera.tool.sql.ooaofooa.body.impl.DerivedAttributeBodySetImpl;
import io.ciera.tool.sql.ooaofooa.body.impl.FunctionBodySetImpl;
import io.ciera.tool.sql.ooaofooa.body.impl.OperationBodySetImpl;
import io.ciera.tool.sql.ooaofooa.body.impl.ProvidedOperationBodySetImpl;
import io.ciera.tool.sql.ooaofooa.body.impl.ProvidedSignalBodySetImpl;
import io.ciera.tool.sql.ooaofooa.body.impl.RequiredOperationBodySetImpl;
import io.ciera.tool.sql.ooaofooa.body.impl.RequiredSignalBodySetImpl;
import io.ciera.tool.sql.ooaofooa.body.impl.StateActionBodySetImpl;
import io.ciera.tool.sql.ooaofooa.body.impl.TransitionActionBodySetImpl;

import java.util.Arrays;
import java.util.List;

import ooaofooa.datatypes.Instance;


public class BodySetImpl extends InstanceSet<BodySet,Body> implements BodySet {

    // attributes
    @Override
    public void setReturn_value( Instance m_return_value ) throws XtumlException {
        for ( Body body : this ) body.setReturn_value( m_return_value );
    }
    @Override
    public void setType( String m_Type ) throws XtumlException {
        for ( Body body : this ) body.setType( m_Type );
    }
    @Override
    public void setAction_ID( UniqueId m_Action_ID ) throws XtumlException {
        for ( Body body : this ) body.setAction_ID( m_Action_ID );
    }
    @Override
    public void setLoopLevel( int m_LoopLevel ) throws XtumlException {
        for ( Body body : this ) body.setLoopLevel( m_LoopLevel );
    }
    @Override
    public void setLabel( String m_Label ) throws XtumlException {
        for ( Body body : this ) body.setLabel( m_Label );
    }
    @Override
    public void setReturnFound( boolean m_ReturnFound ) throws XtumlException {
        for ( Body body : this ) body.setReturnFound( m_ReturnFound );
    }
    @Override
    public void setBlock_ID( UniqueId ref_Block_ID ) throws XtumlException {
        for ( Body body : this ) body.setBlock_ID( ref_Block_ID );
    }
    @Override
    public void setCurrentScope_ID( UniqueId ref_CurrentScope_ID ) throws XtumlException {
        for ( Body body : this ) body.setCurrentScope_ID( ref_CurrentScope_ID );
    }
    @Override
    public void setParsed_Block_ID( UniqueId ref_Parsed_Block_ID ) throws XtumlException {
        for ( Body body : this ) body.setParsed_Block_ID( ref_Parsed_Block_ID );
    }


    // selections
    @Override
    public InvocableObjectSet R432_actions_transformed_from_InvocableObject() throws XtumlException {
        InvocableObjectSet invocableobjectset = new InvocableObjectSetImpl();
        for ( Body body : this ) invocableobjectset.add( body.R432_actions_transformed_from_InvocableObject() );
        return invocableobjectset;
    }
    @Override
    public BlockSet R601_has_committed_Block() throws XtumlException {
        BlockSet blockset = new BlockSetImpl();
        for ( Body body : this ) blockset.addAll( body.R601_has_committed_Block() );
        return blockset;
    }
    @Override
    public BlockSet R612_has_parsed_Block() throws XtumlException {
        BlockSet blockset = new BlockSetImpl();
        for ( Body body : this ) blockset.addAll( body.R612_has_parsed_Block() );
        return blockset;
    }
    @Override
    public BodyInElementSet R640_is_declared_in_BodyInElement() throws XtumlException {
        BodyInElementSet bodyinelementset = new BodyInElementSetImpl();
        for ( Body body : this ) bodyinelementset.add( body.R640_is_declared_in_BodyInElement() );
        return bodyinelementset;
    }
    @Override
    public BlockSet R650_has_parsed_outer_Block() throws XtumlException {
        BlockSet blockset = new BlockSetImpl();
        for ( Body body : this ) blockset.add( body.R650_has_parsed_outer_Block() );
        return blockset;
    }
    @Override
    public BlockSet R666_has_committed_outer_Block() throws XtumlException {
        BlockSet blockset = new BlockSetImpl();
        for ( Body body : this ) blockset.add( body.R666_has_committed_outer_Block() );
        return blockset;
    }
    @Override
    public BodyInComponentSet R694_is_declared_in_BodyInComponent() throws XtumlException {
        BodyInComponentSet bodyincomponentset = new BodyInComponentSetImpl();
        for ( Body body : this ) bodyincomponentset.add( body.R694_is_declared_in_BodyInComponent() );
        return bodyincomponentset;
    }
    @Override
    public BridgeBodySet R698_is_a_BridgeBody() throws XtumlException {
        BridgeBodySet bridgebodyset = new BridgeBodySetImpl();
        for ( Body body : this ) bridgebodyset.add( body.R698_is_a_BridgeBody() );
        return bridgebodyset;
    }
    @Override
    public DerivedAttributeBodySet R698_is_a_DerivedAttributeBody() throws XtumlException {
        DerivedAttributeBodySet derivedattributebodyset = new DerivedAttributeBodySetImpl();
        for ( Body body : this ) derivedattributebodyset.add( body.R698_is_a_DerivedAttributeBody() );
        return derivedattributebodyset;
    }
    @Override
    public FunctionBodySet R698_is_a_FunctionBody() throws XtumlException {
        FunctionBodySet functionbodyset = new FunctionBodySetImpl();
        for ( Body body : this ) functionbodyset.add( body.R698_is_a_FunctionBody() );
        return functionbodyset;
    }
    @Override
    public OperationBodySet R698_is_a_OperationBody() throws XtumlException {
        OperationBodySet operationbodyset = new OperationBodySetImpl();
        for ( Body body : this ) operationbodyset.add( body.R698_is_a_OperationBody() );
        return operationbodyset;
    }
    @Override
    public ProvidedOperationBodySet R698_is_a_ProvidedOperationBody() throws XtumlException {
        ProvidedOperationBodySet providedoperationbodyset = new ProvidedOperationBodySetImpl();
        for ( Body body : this ) providedoperationbodyset.add( body.R698_is_a_ProvidedOperationBody() );
        return providedoperationbodyset;
    }
    @Override
    public ProvidedSignalBodySet R698_is_a_ProvidedSignalBody() throws XtumlException {
        ProvidedSignalBodySet providedsignalbodyset = new ProvidedSignalBodySetImpl();
        for ( Body body : this ) providedsignalbodyset.add( body.R698_is_a_ProvidedSignalBody() );
        return providedsignalbodyset;
    }
    @Override
    public RequiredOperationBodySet R698_is_a_RequiredOperationBody() throws XtumlException {
        RequiredOperationBodySet requiredoperationbodyset = new RequiredOperationBodySetImpl();
        for ( Body body : this ) requiredoperationbodyset.add( body.R698_is_a_RequiredOperationBody() );
        return requiredoperationbodyset;
    }
    @Override
    public RequiredSignalBodySet R698_is_a_RequiredSignalBody() throws XtumlException {
        RequiredSignalBodySet requiredsignalbodyset = new RequiredSignalBodySetImpl();
        for ( Body body : this ) requiredsignalbodyset.add( body.R698_is_a_RequiredSignalBody() );
        return requiredsignalbodyset;
    }
    @Override
    public StateActionBodySet R698_is_a_StateActionBody() throws XtumlException {
        StateActionBodySet stateactionbodyset = new StateActionBodySetImpl();
        for ( Body body : this ) stateactionbodyset.add( body.R698_is_a_StateActionBody() );
        return stateactionbodyset;
    }
    @Override
    public TransitionActionBodySet R698_is_a_TransitionActionBody() throws XtumlException {
        TransitionActionBodySet transitionactionbodyset = new TransitionActionBodySetImpl();
        for ( Body body : this ) transitionactionbodyset.add( body.R698_is_a_TransitionActionBody() );
        return transitionactionbodyset;
    }
    @Override
    public BlockSet R699_has_current_scope_Block() throws XtumlException {
        BlockSet blockset = new BlockSetImpl();
        for ( Body body : this ) blockset.add( body.R699_has_current_scope_Block() );
        return blockset;
    }


    @Override
    public Body nullElement() {
        return BodyImpl.EMPTY_BODY;
    }

    @Override
    public BodySet emptySet() {
      return new BodySetImpl();
    }

    @Override
    public BodySet value() {
        return this;
    }

    @Override
    public List<Body> elements() {
        return Arrays.asList(toArray(new Body[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/body/impl/BodySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.body.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.architecture.invocable.InvocableObjectSet;
import io.ciera.tool.sql.architecture.invocable.impl.InvocableObjectSetImpl;
import io.ciera.tool.sql.ooaofooa.body.BlockSet;
import io.ciera.tool.sql.ooaofooa.body.Body;
import io.ciera.tool.sql.ooaofooa.body.BodyInComponentSet;
import io.ciera.tool.sql.ooaofooa.body.BodyInElementSet;
import io.ciera.tool.sql.ooaofooa.body.BodySet;
import io.ciera.tool.sql.ooaofooa.body.BridgeBodySet;
import io.ciera.tool.sql.ooaofooa.body.DerivedAttributeBodySet;
import io.ciera.tool.sql.ooaofooa.body.FunctionBodySet;
import io.ciera.tool.sql.ooaofooa.body.OperationBodySet;
import io.ciera.tool.sql.ooaofooa.body.ProvidedOperationBodySet;
import io.ciera.tool.sql.ooaofooa.body.ProvidedSignalBodySet;
import io.ciera.tool.sql.ooaofooa.body.RequiredOperationBodySet;
import io.ciera.tool.sql.ooaofooa.body.RequiredSignalBodySet;
import io.ciera.tool.sql.ooaofooa.body.StateActionBodySet;
import io.ciera.tool.sql.ooaofooa.body.TransitionActionBodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.BlockSetImpl;
import io.ciera.tool.sql.ooaofooa.body.impl.BodyInComponentSetImpl;
import io.ciera.tool.sql.ooaofooa.body.impl.BodyInElementSetImpl;
import io.ciera.tool.sql.ooaofooa.body.impl.BridgeBodySetImpl;
import io.ciera.tool.sql.ooaofooa.body.impl.DerivedAttributeBodySetImpl;
import io.ciera.tool.sql.ooaofooa.body.impl.FunctionBodySetImpl;
import io.ciera.tool.sql.ooaofooa.body.impl.OperationBodySetImpl;
import io.ciera.tool.sql.ooaofooa.body.impl.ProvidedOperationBodySetImpl;
import io.ciera.tool.sql.ooaofooa.body.impl.ProvidedSignalBodySetImpl;
import io.ciera.tool.sql.ooaofooa.body.impl.RequiredOperationBodySetImpl;
import io.ciera.tool.sql.ooaofooa.body.impl.RequiredSignalBodySetImpl;
import io.ciera.tool.sql.ooaofooa.body.impl.StateActionBodySetImpl;
import io.ciera.tool.sql.ooaofooa.body.impl.TransitionActionBodySetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;

import ooaofooa.datatypes.Instance;


public class BodySetImpl extends InstanceSet<BodySet,Body> implements BodySet {

    public BodySetImpl() {
    }

    public BodySetImpl(Comparator<? super Body> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setParsed_Block_ID( UniqueId ref_Parsed_Block_ID ) throws XtumlException {
        for ( Body body : this ) body.setParsed_Block_ID( ref_Parsed_Block_ID );
    }
    @Override
    public void setBlock_ID( UniqueId ref_Block_ID ) throws XtumlException {
        for ( Body body : this ) body.setBlock_ID( ref_Block_ID );
    }
    @Override
    public void setReturn_value( Instance m_return_value ) throws XtumlException {
        for ( Body body : this ) body.setReturn_value( m_return_value );
    }
    @Override
    public void setLoopLevel( int m_LoopLevel ) throws XtumlException {
        for ( Body body : this ) body.setLoopLevel( m_LoopLevel );
    }
    @Override
    public void setType( String m_Type ) throws XtumlException {
        for ( Body body : this ) body.setType( m_Type );
    }
    @Override
    public void setReturnFound( boolean m_ReturnFound ) throws XtumlException {
        for ( Body body : this ) body.setReturnFound( m_ReturnFound );
    }
    @Override
    public void setAction_ID( UniqueId m_Action_ID ) throws XtumlException {
        for ( Body body : this ) body.setAction_ID( m_Action_ID );
    }
    @Override
    public void setCurrentScope_ID( UniqueId ref_CurrentScope_ID ) throws XtumlException {
        for ( Body body : this ) body.setCurrentScope_ID( ref_CurrentScope_ID );
    }
    @Override
    public void setLabel( String m_Label ) throws XtumlException {
        for ( Body body : this ) body.setLabel( m_Label );
    }


    // selections
    @Override
    public InvocableObjectSet R432_actions_transformed_from_InvocableObject() throws XtumlException {
        InvocableObjectSet invocableobjectset = new InvocableObjectSetImpl();
        for ( Body body : this ) invocableobjectset.add( body.R432_actions_transformed_from_InvocableObject() );
        return invocableobjectset;
    }
    @Override
    public BlockSet R601_has_committed_Block() throws XtumlException {
        BlockSet blockset = new BlockSetImpl();
        for ( Body body : this ) blockset.addAll( body.R601_has_committed_Block() );
        return blockset;
    }
    @Override
    public BlockSet R612_has_parsed_Block() throws XtumlException {
        BlockSet blockset = new BlockSetImpl();
        for ( Body body : this ) blockset.addAll( body.R612_has_parsed_Block() );
        return blockset;
    }
    @Override
    public BodyInElementSet R640_is_declared_in_BodyInElement() throws XtumlException {
        BodyInElementSet bodyinelementset = new BodyInElementSetImpl();
        for ( Body body : this ) bodyinelementset.add( body.R640_is_declared_in_BodyInElement() );
        return bodyinelementset;
    }
    @Override
    public BlockSet R650_has_parsed_outer_Block() throws XtumlException {
        BlockSet blockset = new BlockSetImpl();
        for ( Body body : this ) blockset.add( body.R650_has_parsed_outer_Block() );
        return blockset;
    }
    @Override
    public BlockSet R666_has_committed_outer_Block() throws XtumlException {
        BlockSet blockset = new BlockSetImpl();
        for ( Body body : this ) blockset.add( body.R666_has_committed_outer_Block() );
        return blockset;
    }
    @Override
    public BodyInComponentSet R694_is_declared_in_BodyInComponent() throws XtumlException {
        BodyInComponentSet bodyincomponentset = new BodyInComponentSetImpl();
        for ( Body body : this ) bodyincomponentset.add( body.R694_is_declared_in_BodyInComponent() );
        return bodyincomponentset;
    }
    @Override
    public BridgeBodySet R698_is_a_BridgeBody() throws XtumlException {
        BridgeBodySet bridgebodyset = new BridgeBodySetImpl();
        for ( Body body : this ) bridgebodyset.add( body.R698_is_a_BridgeBody() );
        return bridgebodyset;
    }
    @Override
    public DerivedAttributeBodySet R698_is_a_DerivedAttributeBody() throws XtumlException {
        DerivedAttributeBodySet derivedattributebodyset = new DerivedAttributeBodySetImpl();
        for ( Body body : this ) derivedattributebodyset.add( body.R698_is_a_DerivedAttributeBody() );
        return derivedattributebodyset;
    }
    @Override
    public FunctionBodySet R698_is_a_FunctionBody() throws XtumlException {
        FunctionBodySet functionbodyset = new FunctionBodySetImpl();
        for ( Body body : this ) functionbodyset.add( body.R698_is_a_FunctionBody() );
        return functionbodyset;
    }
    @Override
    public OperationBodySet R698_is_a_OperationBody() throws XtumlException {
        OperationBodySet operationbodyset = new OperationBodySetImpl();
        for ( Body body : this ) operationbodyset.add( body.R698_is_a_OperationBody() );
        return operationbodyset;
    }
    @Override
    public ProvidedOperationBodySet R698_is_a_ProvidedOperationBody() throws XtumlException {
        ProvidedOperationBodySet providedoperationbodyset = new ProvidedOperationBodySetImpl();
        for ( Body body : this ) providedoperationbodyset.add( body.R698_is_a_ProvidedOperationBody() );
        return providedoperationbodyset;
    }
    @Override
    public ProvidedSignalBodySet R698_is_a_ProvidedSignalBody() throws XtumlException {
        ProvidedSignalBodySet providedsignalbodyset = new ProvidedSignalBodySetImpl();
        for ( Body body : this ) providedsignalbodyset.add( body.R698_is_a_ProvidedSignalBody() );
        return providedsignalbodyset;
    }
    @Override
    public RequiredOperationBodySet R698_is_a_RequiredOperationBody() throws XtumlException {
        RequiredOperationBodySet requiredoperationbodyset = new RequiredOperationBodySetImpl();
        for ( Body body : this ) requiredoperationbodyset.add( body.R698_is_a_RequiredOperationBody() );
        return requiredoperationbodyset;
    }
    @Override
    public RequiredSignalBodySet R698_is_a_RequiredSignalBody() throws XtumlException {
        RequiredSignalBodySet requiredsignalbodyset = new RequiredSignalBodySetImpl();
        for ( Body body : this ) requiredsignalbodyset.add( body.R698_is_a_RequiredSignalBody() );
        return requiredsignalbodyset;
    }
    @Override
    public StateActionBodySet R698_is_a_StateActionBody() throws XtumlException {
        StateActionBodySet stateactionbodyset = new StateActionBodySetImpl();
        for ( Body body : this ) stateactionbodyset.add( body.R698_is_a_StateActionBody() );
        return stateactionbodyset;
    }
    @Override
    public TransitionActionBodySet R698_is_a_TransitionActionBody() throws XtumlException {
        TransitionActionBodySet transitionactionbodyset = new TransitionActionBodySetImpl();
        for ( Body body : this ) transitionactionbodyset.add( body.R698_is_a_TransitionActionBody() );
        return transitionactionbodyset;
    }
    @Override
    public BlockSet R699_has_current_scope_Block() throws XtumlException {
        BlockSet blockset = new BlockSetImpl();
        for ( Body body : this ) blockset.add( body.R699_has_current_scope_Block() );
        return blockset;
    }


    @Override
    public Body nullElement() {
        return BodyImpl.EMPTY_BODY;
    }

    @Override
    public BodySet emptySet() {
      return new BodySetImpl();
    }

    @Override
    public BodySet emptySet(Comparator<? super Body> comp) {
      return new BodySetImpl(comp);
    }

    @Override
    public BodySet value() {
        return this;
    }

    @Override
    public List<Body> elements() {
        return Arrays.asList(toArray(new Body[0]));
    }

}
